==> groupoffice-6.1.80.txz: usr/local/www/groupoffice6/modules/users/language/de.php <==
<?php

$l["cmdCheckColumnRead"]='Lesen';
$l["cmdCheckColumnWrite"]='Schreiben';
$l["cmdHeaderColumnName"]='Modulname';
$l["cmdHeaderGridUserHasAccess"]='Der Benutzer hat Zugriff auf';
$l["userIsMemberOf"]='Der Benutzer ist Mitglied von';
$l["userVisibleTo"]='Der Benutzer ist sichtbar für';
$l["cmdPanelPersonal"]='Persönlich';
$l["cmdPanelPassword"]='Kennwort';
$l["cmdPanelCompany"]='Firma';
$l["cmdPanelPermissions"]='Berechtigungen';
$l["cmdPanelLogin"]='Anmelden';
$l["cmdPanelLookFeel"]='Erscheinungsbild';
$l["cmdPanelSettings"]='Einstellungen';
$l["cmdPanelEnabledMail"]='E-Mail für neue Benutzer aktiviert';
$l["cmdPanelDisabledMail"]='E-Mail für neue Benutzer deaktiviert';
$l["cmdFieldSetPersonal"]='Persönlich';	;
$l["cmdUserWindowTitle"]='Benutzer bearbeiten';
$l["cmdNotificationWindowTitle"]='Benutzer-Einladung (E-Mail) bearbeiten';
$l["cmdMaskSaving"]='Speichern';
$l["cmdFormLabelSubject"]='Betreff';
$l["cmdFormLabelUsername"]='Benutzername';
$l["cmdFormLabelName"]='Name';
$l["cmdFormLabelPassword"]='Kennwort';
$l["cmdFormLabelConfirm"]='Bestätigen';
$l["cmdBoxLabelEnabled"]='Aktiviert';
$l["cmdFormLabelHomepage"]='Webseite';
$l["cmdFormLabelRegistrationTime"]='Registrierungsdatum';
$l["cmdFormLabelLastLogin"]='Letzter Login';
$l["cmdFormLabelTotalLogins"]='Logins gesamt';
$l["numberOfLogins"]='Logins gesamt';
$l["cmdFormLabelTheme"]='Design';
$l["cmdFormLabelStartModule"]='Startmodul';
$l["cmdFormLabelMaximunRows"]='Max. Zeilen in Listen';
$l["cmdFormLabelSortNamesBy"]='Kontakte sortieren nach';
$l["cmdFormLabelLanguage"]='Sprache';
$l["cmdFormLabelTimezone"]='Zeitzone';
$l["cmdFormLabelAdjustDaylight"]='Automatisch auf Sommerzeit umstellen';
$l["cmdFormLabelDateFormat"]='Datumsformat';
$l["cmdFormLabelDateSeperator"]='Datumstrennzeichen';
$l["timeFormat"]='Zeitformat';
$l["cmdFormLabelFirstWeekday"]='Erster Wochentag';
$l["cmdFormLabelThousandSeperator"]='Tausendertrennzeichen';
$l["cmdFormLabelDecimalSeperator"]='Dezimaltrennzeichen';
$l["cmdFormLabelCurrency"]='Währung';
$l["account"]='Benutzerdaten';
$l["companyProfile"]='Firmendaten';
$l["loginInfo"]='Loginstatistik';
$l["changePassword"]='Kennwort ändern';
$l["currentPassword"]='Aktuelles Kennwort';
$l["newPassword"]='Neues Kennwort';
$l["confirmPassword"]='Kennwort bestätigen';
$l["moduleAccess"]='Modulzugriff';
$l["groupMembership"]='Gruppen-Mitgliedschaft';
$l["personalProfile"]='Persönliche Daten';
$l["settings"]='Persönliche Einstellungen';
$l["dmy"]='Tag-Monat-Jahr';
$l["mdy"]='Monat-Tag-Jahr';
$l["jmd"]='Jahr-Monat-Tag';
$l["fullhourformat"]='24 Stunden';
$l["halfhourformat"]='12 Stunden';
$l["sunday"]='Sonntag';
$l["monday"]='Montag';
$l["regionalSettings"]='Regionale Daten';
$l["userSettings"]='Benutzeroptionen';
$l["profile"]='Profil';
$l["maxUsersReached"]='Die maximale Anzahl von Benutzern wurde erreicht. Fragen Sie Ihren Systemadministrator, ob die maximale Benutzeranzahl noch erhöht werden kann.';
$l["group"]='Gruppe';
$l["muteSound"]='Keine Sounds für Ereignisse nutzen';
$l["mailReminders"]='E-Mail-Erinnerungen';
$l["downloadSampleCSV"]='Beispiel-CSV herunterladen';
$l["importText"]='Sie können Benutzer mittels einer CSV-Datei importieren. Um die nötige Formatierung dieser Datei einzuhalten, laden Sie sich zum Vergleich bitte die Beispieldatei herunter.<br />Die erste Zeile muss die Spaltenbezeichnungen enthalten und für jeden neuen Benutzer müssen die folgenden Daten angegeben werden:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]='Benutzen';
$l["manageModule"]='Verwalten';
$l["numberFormat"]='Währungsformat';
$l["importExport"]='Import / Export';
$l["listSeparator"]='Listentrennzeichen';
$l["textSeparator"]='Texttrennzeichen';
$l["deleteWarning"]='WARNUNG!!! Alle Benutzerdaten inkl. Adressbüchern, Projekten, Kalendern, etc. werden unwiderruflich gelöscht!';
$l["lastName"]='Nachname';
$l["firstName"]='Vorname';
$l["sendInvitation"]='Einladung versenden';
$l["contactInfo"]='Kontakt-Info';
$l["popupNotification"]='Popupfenster anzeigen, wenn eine Erinnerung ansteht oder eine neue E-Mail eintrifft';
$l["muteNewMailSound"]='Keine Sounds für E-Mails nutzen';
$l["muteReminderSound"]='Keine Sounds für Erinnerungen nutzen';
$l["showSmilies"]='Smileys anzeigen';
$l["autoPunctuation"]='Großschreibung nach Punkt';
$l['name']='Benutzer';
$l['description']='Modul zur Benutzerverwaltung';
$l['deletePrimaryAdmin']='Sie können den primären Administrator nicht löschen';
$l['deleteYourself']='Sie können sich nicht selbst löschen';
$l['error_username']='Ihr Benutzername enthält ungültige Zeichen';
$l['error_username_exists']='Der Benutzername ist bereits registriert';
$l['error_email_exists']='Die E-Mail-Adresse ist bereits registriert.';
$l['error_match_pass']='Die Passwörter sind nicht identisch';
$l['error_email']='Sie haben eine ungültige E-Mail-Adresse angegeben';
$l['error_user']='Benutzer konnte nicht angelegt werden';
$l['imported']='%s Benutzer importiert';
$l['failed']='Fehlgeschlagen';
$l['incorrectFormat']='Datei hatte nicht das erforderliche CSV-Format';
$l['register_email_subject']='Ihre GroupOffice-Kontodaten';
$l['register_email_body']='Ein GroupOffice-Konto wurde für Sie auf {url} erstellt.
Ihre Logindaten sind:
Benutzername: {username};
Kennwort: {password}';
$l['max_users_reached']='Für dieses System wurde die maximale Benutzeranzahl erreicht.';

$l['dashdmy']='Tag-Monat-Jahr';
$l['slashmdy']='Monat/Tag/Jahr';
$l['dotdmy']='Tag.Monat.Jahr';
$l['slashdmy']='Tag/Monat/Jahr';
$l['slashymd']='Jahr-Monat-Tag';
$l['dotymd']='Jahr.Monat.Tag';
$l['generatePassword']='Erzeuge Kennwort';
$l['generatedPasswordIs']='Das zeugte Kennwort lautet';
$l['updateExistingOnImport']='Vorhandene Nutzer aktualisieren (per Nutzername)';

$l['openContact']='Kontakt öffnen';
$l['showProUsers']='Zeige Professional-Benutzer';

$l['resetState']="Fenster und Spalten zurücksetzen";
$l['resetStateConfirm']='Sind Sie sicher, dass Sie alle Spalten, Fenster- und Spaltengrößen etc. auf die Werkseinstellungen zurücksetzen wollen?';

$l['registrationEmail']='E-Mail Registrierung';
$l['enabledSettingtabs']='Aktiviere Einstellungs-Tabs';

$l['explanation_cf_settingspanels']='Um den Tab für die Zusatzfelder in den Einstellung anzuzeigen, muss sichergestellt sein, dass der Nutzer mindestens Leserechte auf das Zusatzfelder-Modul hat.';
$l['addresslist_panel']= 'Adresslistenelemnt';
$l['show_addresslists_panel']= 'Adresslistenelement anzeigen';
$l['enabled_cf_tabs']= 'Aktivierte Zusatzfelder Tabs';

$l['cmdFormLabelHolidaySet'] = 'Feiertage';

$l['diskSpace'] = 'Festplattenspeicher';
$l['diskQuota'] = 'Festplatten-Kontingent';
$l['spaceUsed'] = 'Davon verwendet';

$l['noReminders']= 'Keine Erinnerungen für mich erstellen';
$l['transferData'] = 'Übertragen';

$l['id']= 'ID';

==> groupoffice-6.2.19.txz: usr/local/www/groupoffice6/modules/users/language/de.php <==
<?php

$l["cmdCheckColumnRead"]='Lesen';
$l["cmdCheckColumnWrite"]='Schreiben';
$l["cmdHeaderColumnName"]='Modulname';
$l["cmdHeaderGridUserHasAccess"]='Der Benutzer hat Zugriff auf';
$l["userIsMemberOf"]='Der Benutzer ist Mitglied von';
$l["userVisibleTo"]='Der Benutzer ist sichtbar für';
$l["cmdPanelPersonal"]='Persönlich';
$l["cmdPanelPassword"]='Kennwort';
$l["cmdPanelCompany"]='Organisation';
$l["cmdPanelPermissions"]='Berechtigungen';
$l["cmdPanelLogin"]='Anmelden';
$l["cmdPanelLookFeel"]='Erscheinungsbild';
$l["cmdPanelSettings"]='Einstellungen';
$l["cmdPanelEnabledMail"]='E-Mail für neue Benutzer aktiviert';
$l["cmdPanelDisabledMail"]='E-Mail für neue Benutzer deaktiviert';
$l["cmdFieldSetPersonal"]='Persönlich';	;
$l["cmdUserWindowTitle"]='Benutzer bearbeiten';
$l["cmdNotificationWindowTitle"]='Benutzer-Einladung (E-Mail) bearbeiten';
$l["cmdMaskSaving"]='Speichern';
$l["cmdFormLabelSubject"]='Betreff';
$l["cmdFormLabelUsername"]='Benutzername';
$l["cmdFormLabelName"]='Name';
$l["cmdFormLabelPassword"]='Kennwort';
$l["cmdFormLabelConfirm"]='Bestätigen';
$l["cmdBoxLabelEnabled"]='Aktiviert';
$l["cmdFormLabelHomepage"]='Webseite';
$l["cmdFormLabelRegistrationTime"]='Registrierungsdatum';
$l["cmdFormLabelLastLogin"]='Letzter Login';
$l["cmdFormLabelTotalLogins"]='Logins gesamt';
$l["numberOfLogins"]='Logins gesamt';
$l["cmdFormLabelTheme"]='Design';
$l["cmdFormLabelStartModule"]='Startmodul';
$l["cmdFormLabelMaximunRows"]='Max. Zeilen in Listen';
$l["cmdFormLabelSortNamesBy"]='Kontakte sortieren nach';
$l["cmdFormLabelLanguage"]='Sprache';
$l["cmdFormLabelTimezone"]='Zeitzone';
$l["cmdFormLabelAdjustDaylight"]='Automatisch auf Sommerzeit umstellen';
$l["cmdFormLabelDateFormat"]='Datumsformat';
$l["cmdFormLabelDateSeperator"]='Datumstrennzeichen';
$l["timeFormat"]='Zeitformat';
$l["cmdFormLabelFirstWeekday"]='Erster Wochentag';
$l["cmdFormLabelThousandSeperator"]='Tausendertrennzeichen';
$l["cmdFormLabelDecimalSeperator"]='Dezimaltrennzeichen';
$l["cmdFormLabelCurrency"]='Währung';
$l["account"]='Benutzerdaten';
$l["companyProfile"]='Organisationsdaten';
$l["loginInfo"]='Loginstatistik';
$l["changePassword"]='Kennwort ändern';
$l["currentPassword"]='Aktuelles Kennwort';
$l["newPassword"]='Neues Kennwort';
$l["confirmPassword"]='Kennwort bestätigen';
$l["moduleAccess"]='Modulzugriff';
$l["groupMembership"]='Gruppen-Mitgliedschaft';
$l["personalProfile"]='Persönliche Daten';
$l["settings"]='Persönliche Einstellungen';
$l["dmy"]='Tag-Monat-Jahr';
$l["mdy"]='Monat-Tag-Jahr';
$l["jmd"]='Jahr-Monat-Tag';
$l["fullhourformat"]='24 Stunden';
$l["halfhourformat"]='12 Stunden';
$l["sunday"]='Sonntag';
$l["monday"]='Montag';
$l["regionalSettings"]='Regionale Daten';
$l["userSettings"]='Benutzeroptionen';
$l["profile"]='Profil';
$l["maxUsersReached"]='Die maximale Anzahl von Benutzern wurde erreicht. Fragen Sie Ihren Systemadministrator, ob die maximale Benutzeranzahl noch erhöht werden kann.';
$l["group"]='Gruppe';
$l["muteSound"]='Keine Sounds für Ereignisse nutzen';
$l["mailReminders"]='E-Mail-Erinnerungen';
$l["downloadSampleCSV"]='Beispiel-CSV herunterladen';
$l["importText"]='Sie können Benutzer mittels einer CSV-Datei importieren. Um die nötige Formatierung dieser Datei einzuhalten, laden Sie sich zum Vergleich bitte die Beispieldatei herunter.<br />Die erste Zeile muss die Spaltenbezeichnungen enthalten und für jeden neuen Benutzer müssen die folgenden Daten angegeben werden:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]='Benutzen';
$l["manageModule"]='Verwalten';
$l["numberFormat"]='Währungsformat';
$l["importExport"]='Import / Export';
$l["listSeparator"]='Listentrennzeichen';
$l["textSeparator"]='Texttrennzeichen';
$l["deleteWarning"]='WARNUNG!!! Alle Benutzerdaten inkl. Adressbüchern, Projekten, Kalendern, etc. werden unwiderruflich gelöscht!';
$l["lastName"]='Nachname';
$l["firstName"]='Vorname';
$l["sendInvitation"]='Einladung versenden';
$l["contactInfo"]='Kontakt-Info';
$l["popupNotification"]='Popupfenster anzeigen, wenn eine Erinnerung ansteht oder eine neue E-Mail eintrifft';
$l["muteNewMailSound"]='Keine Sounds für E-Mails nutzen';
$l["muteReminderSound"]='Keine Sounds für Erinnerungen nutzen';
$l["showSmilies"]='Smileys anzeigen';
$l["autoPunctuation"]='Großschreibung nach Punkt';
$l['name']='Benutzer';
$l['description']='Modul zur Benutzerverwaltung';
$l['deletePrimaryAdmin']='Sie können den primären Administrator nicht löschen';
$l['deleteYourself']='Sie können sich nicht selbst löschen';
$l['error_username']='Ihr Benutzername enthält ungültige Zeichen';
$l['error_username_exists']='Der Benutzername ist bereits registriert';
$l['error_email_exists']='Die E-Mail-Adresse ist bereits registriert.';
$l['error_match_pass']='Die Passwörter sind nicht identisch';
$l['error_email']='Sie haben eine ungültige E-Mail-Adresse angegeben';
$l['error_user']='Benutzer konnte nicht angelegt werden';
$l['imported']='%s Benutzer importiert';
$l['failed']='Fehlgeschlagen';
$l['incorrectFormat']='Datei hatte nicht das erforderliche CSV-Format';
$l['register_email_subject']='Ihre GroupOffice-Kontodaten';
$l['register_email_body']='Ein GroupOffice-Konto wurde für Sie auf {url} erstellt.
Ihre Logindaten sind:
Benutzername: {username};
Kennwort: {password}';
$l['max_users_reached']='Für dieses System wurde die maximale Benutzeranzahl erreicht.';

$l['dashdmy']='Tag-Monat-Jahr';
$l['slashmdy']='Monat/Tag/Jahr';
$l['dotdmy']='Tag.Monat.Jahr';
$l['slashdmy']='Tag/Monat/Jahr';
$l['slashymd']='Jahr-Monat-Tag';
$l['dotymd']='Jahr.Monat.Tag';
$l['generatePassword']='Erzeuge Kennwort';
$l['generatedPasswordIs']='Das zeugte Kennwort lautet';
$l['updateExistingOnImport']='Vorhandene Nutzer aktualisieren (per Nutzername)';

$l['openContact']='Kontakt öffnen';
$l['showProUsers']='Zeige Professional-Benutzer';

$l['resetState']="Fenster und Spalten zurücksetzen";
$l['resetStateConfirm']='Sind Sie sicher, dass Sie alle Spalten, Fenster- und Spaltengrößen etc. auf die Werkseinstellungen zurücksetzen wollen?';

$l['registrationEmail']='E-Mail Registrierung';
$l['enabledSettingtabs']='Aktiviere Einstellungs-Tabs';

$l['explanation_cf_settingspanels']='Um den Tab für die Zusatzfelder in den Einstellung anzuzeigen, muss sichergestellt sein, dass der Nutzer mindestens Leserechte auf das Zusatzfelder-Modul hat.';
$l['addresslist_panel']= 'Adresslistenelemnt';
$l['show_addresslists_panel']= 'Adresslistenelement anzeigen';
$l['enabled_cf_tabs']= 'Aktivierte Zusatzfelder Tabs';

$l['cmdFormLabelHolidaySet'] = 'Feiertage';

$l['diskSpace'] = 'Festplattenspeicher';
$l['diskQuota'] = 'Festplatten-Kontingent';
$l['spaceUsed'] = 'Davon verwendet';

$l['noReminders']= 'Keine Erinnerungen für mich erstellen';
$l['transferData'] = 'Übertragen';

$l['desktopNotificationsActive']= 'Desktopbenachrichtigung aktiv';
$l['id']= 'ID';

$l['popupReminderNotification']= 'Zeige ein Popup-Fenster, wenn eine Erinnerung aktiv wird';
$l['popupEmailNotification']= 'Zeige ein Popup-Fenster, wenn eine eMail ankommt';
